{ lib, pkgs, config,  ... }:
let
    adminer = pkgs.callPackage ../commons/adminer.nix {};
    cfg = config.myServices.websites.florian.production;
    varDir = "/var/lib/ftp/florian";
    env = config.myEnv.websites.florian;
in {
  options.myServices.websites.florian.production.enable = lib.mkEnableOption "enable Florian's website production";

  config = lib.mkIf cfg.enable {
    security.acme.certs."ftp".extraDomains."tellesflorian.com" = null;

    services.websites.env.production.modules = adminer.apache.modules;
    services.websites.env.production.vhostConfs.florian = {
      certName     = "florian";
      certMainHost = "tellesflorian.com";
      hosts        = [ "tellesflorian.com" "www.tellesflorian.com" ];
      root         = "${varDir}/tellesflorian.com";
      extraConfig  = [
        adminer.apache.vhostConf
        ''
        ServerAdmin ${env.server_admin}

        <Directory ${varDir}/tellesflorian.com>
          DirectoryIndex index.php index.htm index.html
          Options Indexes FollowSymLinks MultiViews Includes
          AllowOverride None
          Require all granted
        </Directory>
          ''
      ];
    };
  };
}
