{ adminer }:
rec {
  activationScript = {
    deps = [ "httpd" ];
    text = ''
      install -m 0755 -o ${apache.user} -g ${apache.group} -d /var/lib/php/sessions/adminer
      install -m 0755 -o ${apache.user} -g ${apache.group} -d /var/lib/php/tmp/adminer
      '';
  };
  webRoot = adminer;
  phpFpm = rec {
    socket = "/var/run/phpfpm/adminer.sock";
    pool = ''
      listen = ${socket}
      user = ${apache.user}
      group = ${apache.group}
      listen.owner = ${apache.user}
      listen.group = ${apache.group}
      pm = ondemand
      pm.max_children = 5
      pm.process_idle_timeout = 60
      ;php_admin_flag[log_errors] = on
      ; Needed to avoid clashes in browser cookies (same domain)
      php_value[session.name] = AdminerPHPSESSID
      php_admin_value[open_basedir] = "${webRoot}:/tmp:/var/lib/php/sessions/adminer:/var/lib/php/tmp/adminer"
      php_admin_value[session.save_path] = "/var/lib/php/sessions/adminer"
      php_admin_value[upload_tmp_dir] = "/var/lib/php/tmp/adminer"
      '';
  };
  apache = rec {
    user = "wwwrun";
    group = "wwwrun";
    modules = [ "proxy_fcgi" ];
    webappName = "_adminer";
    root = "/run/current-system/webapps/${webappName}";
    vhostConf = ''
      Alias /adminer ${root}
      <Directory ${root}>
        DirectoryIndex index.php
        <FilesMatch "\.php$">
          SetHandler "proxy:unix:${phpFpm.socket}|fcgi://localhost"
        </FilesMatch>

        Use LDAPConnect
        Require ldap-group cn=users,cn=mysql,cn=pam,ou=services,dc=immae,dc=eu
        Require ldap-group cn=users,cn=postgresql,cn=pam,ou=services,dc=immae,dc=eu
      </Directory>
      '';
  };
}
